/*
 *++
COPYRIGHT:
This file is part of the GSM Suite, a set of programs for
manipulating state machines in a graphical fashion.
Copyright (C) 1996, 1997  G. Andrew Mangogna.

LICENSE:
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.,
59 Temple Place - Suite 330,
Boston, MA  02111-1307, USA.

MODULE:

$RCSfile: MachineGroupDialogDirector.h,v $
$Revision: 1.4 $
$Date: 1997/07/02 04:45:08 $

ABSTRACT:

CONDITIONAL COMPILATION:

MODIFICATION HISTORY:
$Log: MachineGroupDialogDirector.h,v $
Revision 1.4  1997/07/02 04:45:08  andrewm
Added copyright and license notices to the tops of the files.

Revision 1.3  1997/06/06 04:34:26  andrewm
Checkpoint.  Changed the Subject / Observer code to include a
pointer to the changed subject in the call to "update".  This allowed
a given observer to observe muliple subjects.  Then I modified
various dialogs, especially those in that control the various fields
in the state machine to observe multiple subjects as necessary to
insure that all their fields were updated properly.

Revision 1.2  1997/04/08 04:34:30  andrewm
Checkpoint as dialogs are added.
Decided to make sure that the name part of a name/value pair in
the hierarchical file is not used for id purposes.  Specifically
state machine names need to be contained within the machine not as
the key to the machine.

Revision 1.1  1997/03/30 02:07:29  andrewm
Checkpoint.  Things working well. About to change the way
machines are stored in the backing file.

 *--
 */
#ifndef _MachineGroupDialogDirector_h_
#define _MachineGroupDialogDirector_h_

/*
PRAGMAS
*/
#ifdef __GNUG__
#	pragma interface
#endif /* __GNUG__ */

/*
INCLUDE FILES
*/
#include "DialogDirector.h"
#include "Observer.h"

#include <X11/Intrinsic.h>
#include <string>

/*
MACRO DEFINITIONS
*/

/*
CLASS FORWARD REFERENCES
*/

/*
CLASS DEFINITIONS
*/

class MachineGroup ;
class DialogForm ;
class GsmDocument ;
class MenuButton ;
class TextEditor ;

class MachineGroupDialogDirector :
	public DialogDirector,
	public Observer
{
public:
	MachineGroupDialogDirector(const char *name, UIComponent *parent,
		GsmDocument& document) ;
	~MachineGroupDialogDirector() ;

	virtual void show_dialog() ;
	virtual void dismiss_dialog() ;

	virtual void update(const Subject *subject) ;
	virtual void subject_deleted(Subject *subject) ;

	bool modified() const ;
	void modified(bool new_modified) ;

protected:
	void set_author() ;
	void set_revision() ;
	void set_prolog() ;
	void set_epilog() ;
	void edit_prolog() ;
	void edit_epilog() ;

private:
	static void author_entry_cb(Widget widget, XtPointer closure,
		XtPointer callback_data) ;
	static void revision_entry_cb(Widget widget, XtPointer closure,
		XtPointer callback_data) ;

private:
	GsmDocument& _document ;
	MachineGroup *_group ;
	DialogForm *_form ;
	MenuButton *_prolog_button ;
	TextEditor *_prolog_editor ;
	MenuButton *_epilog_button ;
	TextEditor *_epilog_editor ;
	Widget _filename_label ;
	Widget _filesize_label ;
	Widget _modtime_label ;
	Widget _author_entry ;
	Widget _revision_entry ;
	Widget _count_label ;
} ;


#endif /* _MachineGroupDialogDirector_h_ */
